searchData={"items":[{"type":"module","title":"IDeviceDb","doc":"A database of Apple devices.\n\nThis module provides a simple API for querying a database of Apple devices.\nThe database is generated from the Apple Wiki and is stored in the priv directory.\n\nWhen the module is loaded, the database is read from the priv directory and stored in\npersistent terms. This means that the database is only read from disk once and is then\navailable in memory for the lifetime of the application.\n\nThe module provides two functions, `generation_less_than?/2` and `model_less_than?/2`,\nwhich may be used as 'sorters' in the `Enum.sort/2` function. These functions order by\nthe age of the device, with the oldest devices first.","ref":"IDeviceDb.html"},{"type":"function","title":"IDeviceDb.all_devices/0","doc":"Returns a list of all devices in the database.","ref":"IDeviceDb.html#all_devices/0"},{"type":"function","title":"Example - IDeviceDb.all_devices/0","doc":"iex> IDeviceDb.all_devices |> Enum.take(1)\n    [\n      %{\n        finish: \"Black\",\n        identifier: \"iPhone1,1\",\n        generation: \"iPhone\",\n        models: [\"MA501\"],\n        internal_name: \"M68AP\",\n        storage: \"4 GB\"\n      }\n    ]","ref":"IDeviceDb.html#all_devices/0-example"},{"type":"function","title":"IDeviceDb.find_by_model/1","doc":"Finds a device by its model name e.g. `MX132`","ref":"IDeviceDb.html#find_by_model/1"},{"type":"function","title":"Example - IDeviceDb.find_by_model/1","doc":"iex> IDeviceDb.find_by_model(\"MX132\")\n    %{\n      finish: \"Space Gray\",\n      identifier: \"iPhone10,1\",\n      generation: \"iPhone 8\",\n      models: [\"MX132\"],\n      internal_name: \"D20AP\",\n      storage: \"128 GB\"\n    }","ref":"IDeviceDb.html#find_by_model/1-example"},{"type":"function","title":"IDeviceDb.generation_less_than?/2","doc":"Returns true if `g1` is older than `g2`, false otherwise.\n\nIntended to be used as a sorter in `Enum.sort/2`.","ref":"IDeviceDb.html#generation_less_than?/2"},{"type":"function","title":"Example - IDeviceDb.generation_less_than?/2","doc":"iex> Enum.sort([\"iPhone X\", \"iPhone 13 Pro Max\", \"iPhone 5c\"], &IDeviceDb.generation_less_than?/2)\n    [\"iPhone 5c\", \"iPhone X\", \"iPhone 13 Pro Max\"]","ref":"IDeviceDb.html#generation_less_than?/2-example"},{"type":"function","title":"IDeviceDb.id_to_generation/1","doc":"Returns the generation of a device given its identifier e.g. `iPhone13,1`","ref":"IDeviceDb.html#id_to_generation/1"},{"type":"function","title":"Example - IDeviceDb.id_to_generation/1","doc":"iex> IDeviceDb.id_to_generation(\"iPhone13,1\")\n    \"iPhone 12 mini\"","ref":"IDeviceDb.html#id_to_generation/1-example"},{"type":"function","title":"IDeviceDb.identifier_less_than?/2","doc":"Returns true if `i1` is older than `i2`, false otherwise\n\nIntended to be used as a sorter in `Enum.sort/2`.","ref":"IDeviceDb.html#identifier_less_than?/2"},{"type":"function","title":"Example - IDeviceDb.identifier_less_than?/2","doc":"iex> Enum.sort([\"iPhone14,5\", \"iPhone12,8\", \"iPhone10,2\"], &IDeviceDb.identifier_less_than?/2)\n    [\"iPhone10,2\", \"iPhone12,8\", \"iPhone14,5\"]","ref":"IDeviceDb.html#identifier_less_than?/2-example"},{"type":"function","title":"IDeviceDb.model_less_than?/2","doc":"Returns true if `m1` is older than `m2`, false otherwise\n\nIntended to be used as a sorter in `Enum.sort/2`. Note that more than\none model can map to a specific device. When comparing such models,\nthis function will return false regardless of the order of the arguments.","ref":"IDeviceDb.html#model_less_than?/2"},{"type":"function","title":"Example - IDeviceDb.model_less_than?/2","doc":"iex> Enum.sort([\"MU163\", \"MYD13\", \"MQ9X3\"], &IDeviceDb.model_less_than?/2)\n    [\"MQ9X3\", \"MU163\", \"MYD13\"]","ref":"IDeviceDb.html#model_less_than?/2-example"},{"type":"task","title":"mix generate_db","doc":"Regenerate the device database from the Apple Wiki","ref":"Mix.Tasks.GenerateDb.html"},{"type":"extras","title":"MIT License","doc":"# MIT License\n\nCopyright (c) 2025 Nick Gunn\n\nPermission is hereby granted, free of charge, to any person obtaining\na copy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE\nLIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION\nOF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION\nWITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"},{"type":"extras","title":"CHANGELOG","doc":"# CHANGELOG","ref":"changelog.html"},{"type":"extras","title":"1.0.0 - 2025-02-05 - CHANGELOG","doc":"- Breaking change. Renamed `find_by_identifier/1` to `id_to_generation/1`\n\n- Added comparision functions","ref":"changelog.html#1-0-0-2025-02-05"},{"type":"extras","title":"0.1.3 - 2025-02-03 - CHANGELOG","doc":"- Initial revision","ref":"changelog.html#0-1-3-2025-02-03"},{"type":"extras","title":"IDeviceDb","doc":"# IDeviceDb\n\n[![Hex](https://img.shields.io/hexpm/v/idevice_db.svg)](https://hex.pm/packages/idevice_db)\n[![Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/idevice_db/)\n[![License](https://img.shields.io/hexpm/l/idevice_db.svg)](https://github.com/ausimian/idevice_db/blob/main/LICENSE.md)\n![github actions badge](https://github.com/ausimian/idevice_db/actions/workflows/build.yaml/badge.svg)\n\nA database of Apple devices.\n\nThis package provides a simple API for querying a database of Apple devices.\nThe database is generated from [The Apple Wiki](https://theapplewiki.com/wiki/Models)\nand is stored in the `priv` directory of the application.\n\nWhen the application is loaded, the database is read from the priv directory and stored in\npersistent terms. This means that the database is only read from disk once and is then\navailable in memory for the lifetime of the application.","ref":"readme.html"},{"type":"extras","title":"Examples - IDeviceDb","doc":"iex> IDeviceDb.find_by_model(\"MWHG2\")\n    %{\n      finish: \"Gold\",\n      identifier: \"iPhone12,5\",\n      models: [\"MWHG2\"],\n      generation: \"iPhone 11 Pro Max\",\n      internal_name: \"D431AP\",\n      storage: \"64 GB\"\n    }","ref":"readme.html#examples"},{"type":"extras","title":"Generating the data - IDeviceDb","doc":"The `priv/devices.json` file may be regenerated by running `mix generate_db`.","ref":"readme.html#generating-the-data"},{"type":"extras","title":"Installation - IDeviceDb","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `idevice_db` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:idevice_db, \"~> 1.0.0\"}\n  ]\nend\n```","ref":"readme.html#installation"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}